@@ -3,7 +3,7 @@
  * Print setup
  * Colour Management setup
  *
- * Copyright (c) 2004-2007 by Alastair M. Robinson
+ * Copyright (c) 2004-2008 by Alastair M. Robinson
  * Distributed under the terms of the GNU General Public License -
  * see the file named "COPYING" for more details.
  *
@@ -95,7 +95,7 @@ static void driver_changed(GtkWidget *wid,gpointer data)
 	struct printsetupdata *cbd=(struct printsetupdata *)data;
 	PrintOutput *po=&cbd->state->printoutput;
 
-	char *driver=po->FindString("Driver");
+	const char *driver=po->FindString("Driver");
 	cerr << "Driver=" << driver << endl;
 
 	if(!(cbd->state->printer.SetDriver(po->FindString("Driver"))))
@@ -134,7 +134,7 @@ void PrintSetup_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 
 	cerr << "Created PrintOutput widget..." << endl;
 
-	dialogdata.custompage.name="Output";
+	dialogdata.custompage.name=_("Output");
 	dialogdata.custompage.widget=dialogdata.printoutput;
 	
 	dialogdata.optionbook=stpui_optionbook_new(state.printer.stpvars,&dialogdata.custompage,1);
@@ -184,7 +184,7 @@ void About_Dialog(GtkWindow *parent)
 	
 	GtkWidget *label=gtk_label_new("PhotoPrint "
 	PACKAGE_VERSION
-	" - copyright (c) 2004-2007\n"
+	" - copyright (c) 2004-2008\n"
 	"by Alastair M. Robinson (amr@blackfiveservices.co.uk)\nDistributed under the terms\nof the GNU General Public Licence.\n"
 	"See the file 'COPYING' for more details.");
 	gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_CENTER);
@@ -388,7 +388,6 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
 		NULL);
-//	gtk_window_set_default_size(GTK_WINDOW(dialog),250,350);
 
 	hbox=gtk_hbox_new(FALSE,5);
 	GtkWidget *filechooser = gtk_file_chooser_widget_new (GTK_FILE_CHOOSER_ACTION_SAVE);
@@ -407,37 +406,22 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	// Filename
 
 	GtkWidget *label;
-#if 0
-	label=gtk_label_new("Filename:");
-	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
-	gtk_widget_show(label);
-	
-	hbox=gtk_hbox_new(FALSE,0);
-	GtkWidget *fnentry=gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(fnentry),TRUE,TRUE,0);
-	gtk_widget_show(fnentry);
-	
-	GtkWidget *fnbutton=gtk_button_new_with_label("...");
-	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(fnbutton),FALSE,FALSE,0);
-	g_signal_connect(fnbutton,"clicked",G_CALLBACK(tiff_filedialog),fnentry);
-	gtk_widget_show(fnbutton);
-	
-	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,0,1);
-	gtk_widget_show(hbox);
-#endif
 
 	// Pages
 
-	hbox=gtk_hbox_new(FALSE,0);
-
 	label=gtk_label_new(_("Page range:"));
 	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
 	gtk_widget_show(label);
 
+	hbox=gtk_hbox_new(FALSE,0);
+
 	GtkWidget *pagesentry=gtk_entry_new();
+	gtk_entry_set_width_chars(GTK_ENTRY(pagesentry),7);
 	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(pagesentry),TRUE,TRUE,0);
 	gtk_widget_show(pagesentry);
 
+	// Resolution
+
 	label=gtk_label_new(_("Resolution (dpi):"));
 	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(label),TRUE,TRUE,20);
 	gtk_widget_show(label);
@@ -446,15 +430,17 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(resspin),TRUE,TRUE,0);
 	gtk_widget_show(resspin);
 
+	GtkWidget *deepcolour=gtk_check_button_new_with_label(_("Save as 16-bit:"));
+	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(deepcolour),TRUE,TRUE,20);
+	gtk_widget_show(deepcolour);
+
 	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,1,2);
 	gtk_widget_show(hbox);
 
-	// Resolution
+//	hbox=gtk_hbox_new(FALSE,5);
 
-	hbox=gtk_hbox_new(FALSE,5);
-
-	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,2,3);
-	gtk_widget_show(hbox);
+//	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,2,3);
+//	gtk_widget_show(hbox);
 
 
 	// Colour management
@@ -506,6 +492,7 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 					const char *pagerange=gtk_entry_get_text(GTK_ENTRY(pagesentry));
 					char *outputfilename=gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filechooser));
 					int res=int(gtk_spin_button_get_value(GTK_SPIN_BUTTON(resspin)));
+					bool save16bit=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(deepcolour));
 		
 					if(outputfilename)
 					{
@@ -567,9 +554,10 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 									cerr << "Set profile - saving..." << endl;
 								}
 
-								TIFFSaver ts(ftmp,is);
+								TIFFSaver ts(ftmp,is,save16bit);
 								ts.SetProgress(&p);
 								ts.Save();
+								delete is;
 							}
 							
 							free(ftmp);
@@ -609,7 +597,7 @@ void ExportJPEG_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_widget_show(filechooser);
 	gtk_widget_show(hbox);
 
-	GtkWidget *table=gtk_table_new(2,3,FALSE);
+	GtkWidget *table=gtk_table_new(2,5,FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(table),5);
 	gtk_table_set_col_spacings(GTK_TABLE(table),0);
 	gtk_table_set_row_spacings(GTK_TABLE(table),5);
@@ -632,6 +620,8 @@ void ExportJPEG_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(pagesentry),TRUE,TRUE,0);
 	gtk_widget_show(pagesentry);
 
+	// Resolution
+
 	label=gtk_label_new(_("Resolution (dpi):"));
 	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(label),TRUE,TRUE,20);
 	gtk_widget_show(label);
@@ -643,23 +633,33 @@ void ExportJPEG_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,1,2);
 	gtk_widget_show(hbox);
 
-	// Resolution
+
+	// JPEG Quality
 
 	hbox=gtk_hbox_new(FALSE,5);
 
 	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,2,3);
 	gtk_widget_show(hbox);
 
+	label=gtk_label_new(_("JPEG Quality:"));
+	gtk_misc_set_alignment(GTK_MISC(label),0.95,0.5);
+	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(label),TRUE,TRUE,0);
+	gtk_widget_show(label);
+
+	GtkWidget *qualspin=gtk_spin_button_new_with_range(60,100,1);
+	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(qualspin),FALSE,FALSE,0);
+	gtk_widget_show(qualspin);
+
 
 	// Colour management
 
 	GtkWidget *outputprof=profileselector_new(&state.profilemanager,IS_TYPE_NULL,true);
-	gtk_table_attach_defaults(GTK_TABLE(table),outputprof,1,2,3,4);
+	gtk_table_attach_defaults(GTK_TABLE(table),outputprof,1,2,4,5);
 	gtk_widget_show(outputprof);
 
 	GtkWidget *profactive=gtk_check_button_new_with_label(_("Output Profile:"));
 	g_signal_connect(G_OBJECT(profactive),"toggled",G_CALLBACK(profenable_changed),outputprof);
-	gtk_table_attach_defaults(GTK_TABLE(table),profactive,0,1,3,4);
+	gtk_table_attach_defaults(GTK_TABLE(table),profactive,0,1,4,5);
 	gtk_widget_show(profactive);
 
 #ifdef WIN32
@@ -668,10 +668,11 @@ void ExportJPEG_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	char *dirname=substitute_homedir("$HOME");
 #endif
 	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(filechooser),dirname);
-	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(filechooser),"exported.tif");
+	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(filechooser),"exported.jpg");
 	free(dirname);
 
 	gtk_entry_set_text(GTK_ENTRY(pagesentry),"1-");
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(qualspin),85.0);
 
 	const char *fn=state.profilemanager.FindString("ExportProfile");
 	if((!fn) || (strlen(fn)==0))
@@ -700,7 +701,7 @@ void ExportJPEG_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 					const char *pagerange=gtk_entry_get_text(GTK_ENTRY(pagesentry));
 					const char *outputfilename=gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filechooser));
 					int res=int(gtk_spin_button_get_value(GTK_SPIN_BUTTON(resspin)));
-		
+					int quality=int(gtk_spin_button_get_value(GTK_SPIN_BUTTON(qualspin)));
 					if(outputfilename)
 					{
 						state.profilemanager.SetInt("ExportProfileActive",profileactive);
@@ -740,9 +741,10 @@ void ExportJPEG_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 									cerr << "Set profile - saving..." << endl;
 								}
 
-								JPEGSaver ts(ftmp,is);
+								JPEGSaver ts(ftmp,is,quality);
 								ts.SetProgress(&p);
 								ts.Save();
+								delete is;
 							}
 							
 							free(ftmp);
