@@ -1,12 +1,16 @@
-#include "../profilemanager/lcmswrapper.h"
+#include <iostream>
+
+#include "lcmswrapper.h"
 #include "imagesource.h"
 
-ImageSource::ImageSource() : embeddedprofile(NULL), rowbuffer(NULL)
+using namespace std;
+
+ImageSource::ImageSource() : embeddedprofile(NULL), embprofowned(false), rowbuffer(NULL)
 {
 }
 
 
-ImageSource::ImageSource(ImageSource *src) : rowbuffer(NULL)
+ImageSource::ImageSource(ImageSource *src) : embprofowned(false), rowbuffer(NULL)
 {
 	width=src->width;
 	height=src->height;
@@ -24,6 +28,8 @@ ImageSource::~ImageSource()
 {
 	if(rowbuffer)
 		free(rowbuffer);
+	if(embeddedprofile && embprofowned)
+		delete embeddedprofile;
 }
 
 
@@ -47,9 +53,11 @@ CMSProfile *ImageSource::GetEmbeddedProfile()
 }
 
 
-void ImageSource::SetEmbeddedProfile(CMSProfile *profile)
+void ImageSource::SetEmbeddedProfile(CMSProfile *profile,bool owned)
 {
-	if(embeddedprofile)
+	if(embeddedprofile && embprofowned)
 		delete embeddedprofile;
 	embeddedprofile=profile;
+	embprofowned=owned;
 }
+
