@@ -27,7 +27,7 @@ class ImageSource
 	void MakeRowBuffer();
 	void SetResolution(double xr,double yr);
 	CMSProfile *GetEmbeddedProfile();
-	void SetEmbeddedProfile(CMSProfile *profile);
+	void SetEmbeddedProfile(CMSProfile *profile,bool assumeownership=false);
 	int width,height;
 	enum IS_TYPE type;
 	int samplesperpixel;
@@ -35,6 +35,7 @@ class ImageSource
 	bool randomaccess;
 	protected:
 	CMSProfile *embeddedprofile;
+	bool embprofowned;
 	int currentrow;
 	ISDataType *rowbuffer;
 };
