@@ -15,7 +15,7 @@
 #include <math.h>
 
 #include "imagesource_segmentmask.h"
-#include "../support/circlemontage.h"
+#include "circlemontage.h"
 
 using namespace std;
 
