@@ -284,7 +284,7 @@ ImageSource_TIFF::ImageSource_TIFF(const char *filename)
 	strips=NULL;
 
 	int largestimage=0;
-	int imagecount=CountTIFFDirs(filename,largestimage);
+	CountTIFFDirs(filename,largestimage);
 
 	if(!(file=TIFFOpen(filename,"r")))
 	{
@@ -379,11 +379,7 @@ ImageSource_TIFF::ImageSource_TIFF(const char *filename)
 
 	if(TIFFGetField(file, TIFFTAG_ICCPROFILE, &proflen, &profbuffer))
 	{
-		embeddedprofile = new CMSProfile(profbuffer,proflen);
-	}
-	else
-	{
-		embeddedprofile=NULL;
+		SetEmbeddedProfile(new CMSProfile(profbuffer,proflen),true);
 	}
 
 	if(resunit==RESUNIT_CENTIMETER)
