@@ -13,8 +13,10 @@
 
 #include <gdk/gdkpixbuf.h>
 
-#include "imagesource/imagesource.h"
+#include "imagesource.h"
+#include "progress.h"
 
-GdkPixbuf *pixbuf_from_imagesource(ImageSource *is,int redbg8=255,int greenbg8=255,int bluebg8=255);
+GdkPixbuf *pixbuf_from_imagesource(ImageSource *is,
+	int redbg8=255,int greenbg8=255,int bluebg8=255,Progress *prog=NULL);
 
 #endif
