@@ -73,6 +73,16 @@ void Layout_Carousel_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypo
 }
 
 
+void Layout_Carousel_ImageInfo::FlushThumbnail()
+{
+	// Because the carousel is built as a whole, we have to flush the cached preview
+	// along with any obsolete thumbnails.
+	Layout_ImageInfo::FlushThumbnail();
+	Layout_Carousel *lc=(Layout_Carousel *)&layout;
+	lc->FlushPreview();
+}
+
+
 LayoutRectangle *Layout_Carousel_ImageInfo::GetBounds()
 {
 	Layout_Carousel *l=(Layout_Carousel *)&layout;
@@ -144,6 +154,8 @@ void Layout_Carousel::CopyImage(Layout_ImageInfo *ii)
 	cii->segment=ct-1;
 	if(ct>segments)
 		SetSegments(ct);
+
+	FlushPreview();
 }
 
 
@@ -192,10 +204,10 @@ ImageSource *Layout_Carousel::GetImageSource(int page,CMColourDevice target,CMTr
 	
 					mask=new ImageSource_SegmentMask(targetseg,true);
 					source=new ImageSource_Crop(source,fit->xoffset,fit->yoffset,mask->width,mask->height);
-	
+
 					source=new ImageSource_Mask(source,mask);
 					mon->Add(source,targetseg->x,targetseg->y);
-			
+
 					delete fit;
 				}
 			}
@@ -344,7 +356,7 @@ void Layout_Carousel::RenderPreview(int width,int height)
 	{
 		if(imagelist)
 		{
-			ImageSource_Montage *mon=new ImageSource_Montage(IS_TYPE_RGB,72);
+			ImageSource_Montage *mon=new ImageSource_Montage(IS_TYPE_RGBA,72);
 
 			GetImageableArea();
 
@@ -356,7 +368,7 @@ void Layout_Carousel::RenderPreview(int width,int height)
 			ImageSource *source=NULL;
 			ImageSource *mask=NULL;
 			CMSegment *target=NULL;
-	
+
 			for(int s=0;s<segments;s+=2)
 			{
 				Layout_ImageInfo *img=GetNthImage(currentpage,s);
@@ -366,21 +378,21 @@ void Layout_Carousel::RenderPreview(int width,int height)
 					GdkPixbuf *thumbnail=img->GetThumbnail();
 					source=new ImageSource_GdkPixbuf(thumbnail);
 					LayoutRectangle r(source->width,source->height);
-	
+
 					target=c.GetSegmentExtent(s);
-			
+
 					RectFit *fit=r.Fit(*target,true,PP_ROTATION_NONE,img->crop_hpan,img->crop_vpan);
 					if(fit->rotation)
 						source=new ImageSource_Rotate(source,270);
-			
+
 					source=ISScaleImageBySize(source,fit->width,fit->height,IS_SCALING_NEARESTNEIGHBOUR);
-	
+
 					mask=new ImageSource_SegmentMask(target,true);
 					source=new ImageSource_Crop(source,fit->xoffset,fit->yoffset,mask->width,mask->height);
 	
 					source=new ImageSource_Mask(source,mask);
 					mon->Add(source,target->x,target->y);
-			
+
 					delete fit;
 				}
 			}
@@ -435,7 +447,6 @@ void Layout_Carousel::DrawPreview(GtkWidget *widget,int xpos,int ypos,int width,
 
 	if(preview)
 	{
-
 		gdk_draw_pixbuf(widget->window,NULL,preview,
 			0,0,
 			xpos,ypos,
@@ -513,6 +524,22 @@ int Layout_Carousel::GetInnerRadius()
 }
 
 
+int Layout_Carousel::FreeSlots()
+{
+	int totalslots=segments;
+	int count=0;
+	int c=g_list_length(imagelist);
+	for(int i=0;i<c;++i)
+	{
+		GList *element=g_list_nth(imagelist,i);
+		Layout_Carousel_ImageInfo *ii=(Layout_Carousel_ImageInfo *)element->data;
+		if(ii->page==currentpage)
+			++count;
+	}
+	return(totalslots-count);
+}
+
+
 Layout_Carousel_ImageInfo *Layout_Carousel::ImageAt(int page,int segment)
 {
 	Layout_Carousel_ImageInfo *result=NULL;
@@ -560,5 +587,5 @@ Layout_ImageInfo *Layout_Carousel::ImageAtCoord(int x,int y)
 
 int Layout_Carousel::GetCapabilities()
 {
-	return(PPLAYOUT_PROFILE|PPLAYOUT_EFFECTS);
+	return(PPLAYOUT_PROFILE|PPLAYOUT_EFFECTS|PPLAYOUT_DUPLICATE);
 }
