@@ -27,6 +27,7 @@ class Layout_Carousel : public Layout
 	int AddImage(const char *filename,bool allowcropping=true,PP_ROTATION rotation=PP_ROTATION_AUTO);
 	void CopyImage(Layout_ImageInfo *ii);
 	void PlaceImage(const char *filename);
+	int FreeSlots();
 	void Reflow();
 	virtual void LayoutToDB(LayoutDB &db);
 	virtual void DBToLayout(LayoutDB &db);
@@ -68,6 +69,7 @@ class Layout_Carousel_ImageInfo : public Layout_ImageInfo
 	Layout_Carousel_ImageInfo(Layout_Carousel &layout,Layout_ImageInfo *ii,int page,bool allowcropping=false, PP_ROTATION rotation=PP_ROTATION_AUTO);
 	virtual ~Layout_Carousel_ImageInfo();
 	void DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int width,int height);
+	void FlushThumbnail();
 	virtual LayoutRectangle *GetBounds();
 	int segment;
 	private:
