@@ -100,6 +100,8 @@ void Layout_NUp::Reflow()
 	int column=-1;
 	int page=0;
 
+	CancelRenderThreads();
+
 	for(unsigned int i=0;i<g_list_length(imagelist);++i)
 	{
 		++column;
@@ -149,6 +151,22 @@ void Layout_NUp::PlaceImage(const char *filename,int page,int row, int column,bo
 }
 
 
+int Layout_NUp::FreeSlots()
+{
+	int totalslots=GetRows()*GetColumns();
+	int count=0;
+	int c=g_list_length(imagelist);
+	for(int i=0;i<c;++i)
+	{
+		GList *element=g_list_nth(imagelist,i);
+		Layout_NUp_ImageInfo *ii=(Layout_NUp_ImageInfo *)element->data;
+		if(ii->page==currentpage)
+			++count;
+	}
+	return(totalslots-count);
+}
+
+
 void Layout_NUp::FindFirstFree(int &page,int &row,int &column)
 {
 	page=0;
@@ -205,7 +223,7 @@ void Layout_NUp::CopyImage(Layout_ImageInfo *ii)
 {
 	int page,row,column;
 	FindFirstFree(page,row,column);
-	ii=new Layout_NUp_ImageInfo(*this,ii,row,column,page,false);
+	ii=new Layout_NUp_ImageInfo(*this,ii,row,column,page,ii->allowcropping,ii->rotation);
 	imagelist=g_list_append(imagelist,ii);
 	if(page>=pages)
 		++pages;
@@ -215,105 +233,98 @@ void Layout_NUp::CopyImage(Layout_ImageInfo *ii)
 ImageSource *Layout_NUp::GetImageSource(int page,CMColourDevice target,CMTransformFactory *factory,int res)
 {
 	ImageSource *result=NULL;
-	try
+	if(imagelist)
 	{
-		if(imagelist)
+		enum IS_TYPE colourspace=GetColourSpace(target);
+
+		IS_ScalingQuality qual=IS_ScalingQuality(state.FindInt("ScalingQuality"));
+		if(!res)
+			res=state.FindInt("RenderingResolution");
+
+		ImageSource_Montage *mon=new ImageSource_Montage(colourspace,res);
+
+		Layout_NUp_ImageInfo *ii=(Layout_NUp_ImageInfo *)FirstImage();
+		while(ii)
 		{
-			enum IS_TYPE colourspace=GetColourSpace(target);
-
-			IS_ScalingQuality qual=IS_ScalingQuality(state.FindInt("ScalingQuality"));
-			if(!res)
-				res=state.FindInt("RenderingResolution");
-
-			ImageSource_Montage *mon=new ImageSource_Montage(colourspace,res);
-
-			Layout_NUp_ImageInfo *ii=(Layout_NUp_ImageInfo *)FirstImage();
-			while(ii)
+			if(ii->page==page)
 			{
-				if(ii->page==page)
+				ImageSource *img=ii->GetImageSource(target,factory);
+				if(img)
 				{
-					ImageSource *img=ii->GetImageSource(target,factory);
-					if(img)
-					{
-						LayoutRectangle r(img->width,img->height);
-						LayoutRectangle *target=GetLayoutRectangle(ii->row,ii->column);
-						double scale=res;
-						scale/=72.0;
-						target->Scale(scale);
-						
-						RectFit *fit=r.Fit(*target,ii->allowcropping,ii->rotation,ii->crop_hpan,ii->crop_vpan);
+					LayoutRectangle r(img->width,img->height);
+					LayoutRectangle *target=GetLayoutRectangle(ii->row,ii->column);
+					double scale=res;
+					scale/=72.0;
+					target->Scale(scale);
+					
+					RectFit *fit=r.Fit(*target,ii->allowcropping,ii->rotation,ii->crop_hpan,ii->crop_vpan);
 
-						if(fit->rotation)
-							img=new ImageSource_Rotate(img,fit->rotation);
-						
-						img=ISScaleImageBySize(img,fit->width,fit->height,qual);
-						img->SetResolution(res,res);
-						
-						if(fit->width>target->w)
-							fit->width=target->w;
-						if(fit->height>target->h)
-							fit->height=target->h;
+					if(fit->rotation)
+						img=new ImageSource_Rotate(img,fit->rotation);
+					
+					img=ISScaleImageBySize(img,fit->width,fit->height,qual);
+					img->SetResolution(res,res);
+					
+					if(fit->width>target->w)
+						fit->width=target->w;
+					if(fit->height>target->h)
+						fit->height=target->h;
 
-						if(img->width<fit->width)
-							fit->width=img->width;
-						if(img->height<fit->height)
-							fit->height=img->height;
+					if(img->width<fit->width)
+						fit->width=img->width;
+					if(img->height<fit->height)
+						fit->height=img->height;
 
-						if(ii->allowcropping)
-							img=new ImageSource_Crop(img,fit->xoffset,fit->yoffset,fit->width,fit->height);
+					if(ii->allowcropping)
+						img=new ImageSource_Crop(img,fit->xoffset,fit->yoffset,fit->width,fit->height);
 
-						img=ii->ApplyMask(img);
+					img=ii->ApplyMask(img);
 
-						mon->Add(img,fit->xpos,fit->ypos);
-						delete fit;
-					}
+					mon->Add(img,fit->xpos,fit->ypos);
+					delete fit;
 				}
-				ii=(Layout_NUp_ImageInfo *)NextImage();
-			}
-			result=mon;
-
-			// Load background image, if present...
-			if(backgroundfilename)
-			{
-				ImageSource *is=ISLoadImage(backgroundfilename);
-
-				IS_TYPE colourspace=GetColourSpace(target);
-
-				if(STRIP_ALPHA(is->type)==IS_TYPE_GREY)
-					is=new ImageSource_Promote(is,colourspace);
-
-				if(STRIP_ALPHA(is->type)==IS_TYPE_BW)
-					is=new ImageSource_Promote(is,colourspace);
-
-				CMSTransform *transform=NULL;
-
-				if(factory)
-				{
-					CMSProfile *emb=is->GetEmbeddedProfile();
-					if(emb)
-					{
-						cerr << "Has embedded profile..." << endl;
-						transform=factory->GetTransform(target,emb);
-					}
-					else
-					{
-						cerr << "No embedded profile - using default" << endl;
-						transform=factory->GetTransform(target,IS_TYPE(STRIP_ALPHA(is->type)));
-					}
-
-					if(transform)
-						is=new ImageSource_CMS(is,transform);
-				}
-				if((is->width<is->height)^(pagewidth<pageheight))
-					is=new ImageSource_Rotate(is,90);
-				is=ISScaleImageBySize(is,(pagewidth*res)/72,(pageheight*res)/72,qual);
-				mon->Add(is,0,0);
 			}
+			ii=(Layout_NUp_ImageInfo *)NextImage();
+		}
+		result=mon;
+
+		// Load background image, if present...
+		if(backgroundfilename)
+		{
+			ImageSource *is=ISLoadImage(backgroundfilename);
+
+			IS_TYPE colourspace=GetColourSpace(target);
+
+			if(STRIP_ALPHA(is->type)==IS_TYPE_GREY)
+				is=new ImageSource_Promote(is,colourspace);
+
+			if(STRIP_ALPHA(is->type)==IS_TYPE_BW)
+				is=new ImageSource_Promote(is,colourspace);
+
+			CMSTransform *transform=NULL;
+
+			if(factory)
+			{
+				CMSProfile *emb=is->GetEmbeddedProfile();
+				if(emb)
+				{
+					cerr << "Has embedded profile..." << endl;
+					transform=factory->GetTransform(target,emb);
+				}
+				else
+				{
+					cerr << "No embedded profile - using default" << endl;
+					transform=factory->GetTransform(target,IS_TYPE(STRIP_ALPHA(is->type)));
+				}
+
+				if(transform)
+					is=new ImageSource_CMS(is,transform);
+			}
+			if((is->width<is->height)^(pagewidth<pageheight))
+				is=new ImageSource_Rotate(is,90);
+			is=ISScaleImageBySize(is,(pagewidth*res)/72,(pageheight*res)/72,qual);
+			mon->Add(is,0,0);
 		}
-	}
-	catch (const char *msg)
-	{
-		ErrorMessage_Dialog(msg);
 	}
 	return(result);
 }
@@ -404,47 +415,6 @@ Layout_ImageInfo *Layout_NUp::ImageAtCoord(int x,int y)
 
 int Layout_NUp::GetCapabilities()
 {
-	return(PPLAYOUT_CROP|PPLAYOUT_ROTATE|PPLAYOUT_MASK|PPLAYOUT_EFFECTS|PPLAYOUT_BACKGROUND|PPLAYOUT_PROFILE);
+	return(PPLAYOUT_CROP|PPLAYOUT_ROTATE|PPLAYOUT_MASK|PPLAYOUT_EFFECTS|PPLAYOUT_BACKGROUND|PPLAYOUT_PROFILE|PPLAYOUT_DUPLICATE);
 }
 
-
-void Layout_NUp::DrawPreview(GtkWidget *widget,int xpos,int ypos,int width,int height)
-{
-	double scale=width;
-	scale/=pagewidth;
-
-	if(background)
-	{
-		if(backgroundtransformed)
-			g_object_unref(backgroundtransformed);
-		backgroundtransformed=NULL;
-		
-		int bw=gdk_pixbuf_get_width(background);
-		int bh=gdk_pixbuf_get_height(background);
-
-		int rotation=0;
-		if((bw<bh)^(width<height))
-			rotation=90;
-	
-		GdkPixbuf *tmp;
-		switch(rotation)
-		{
-			case 0:
-				backgroundtransformed=gdk_pixbuf_scale_simple(background,width,height,GDK_INTERP_NEAREST);
-				break;
-			case 90:
-				tmp=gdk_pixbuf_rotate_simple(background,GDK_PIXBUF_ROTATE_COUNTERCLOCKWISE);
-				backgroundtransformed=gdk_pixbuf_scale_simple(tmp,width,height,GDK_INTERP_NEAREST);
-				g_object_unref(G_OBJECT(tmp));
-				break;
-		}
-	
-		gdk_draw_pixbuf(widget->window,NULL,backgroundtransformed,
-			0,0,
-			xpos,ypos,
-			width,height,
-			GDK_RGB_DITHER_NONE,0,0);
-	}
-	
-	Layout::DrawPreview(widget,xpos,ypos,width,height);
-}
