@@ -426,3 +426,29 @@ int Layout_Poster::GetCapabilities()
 {
 	return(PPLAYOUT_CROP|PPLAYOUT_ROTATE|PPLAYOUT_MASK|PPLAYOUT_EFFECTS|PPLAYOUT_PROFILE);
 }
+
+
+Layout_ImageInfo *Layout_Poster::FirstSelected()
+{
+	Layout_ImageInfo *ii=FirstImage();
+	while(ii)
+	{
+		if(ii->page==currentposter)
+			return(ii);
+		ii=NextSelected();
+	}
+	return(NULL);
+}
+
+
+Layout_ImageInfo *Layout_Poster::NextSelected()
+{
+	Layout_ImageInfo *ii=NextImage();
+	while(ii)
+	{
+		if(ii->page==currentposter)
+			return(ii);
+		ii=NextSelected();
+	}
+	return(NULL);
+}
