@@ -46,6 +46,8 @@ class Layout_Poster : public Layout
 	virtual void SetCurrentPage(int page);
 	ImageSource *GetImageSource(int page,CMColourDevice target=CM_COLOURDEVICE_PRINTER,CMTransformFactory *factory=NULL,int res=0);
 	void UpdatePageSize();
+	virtual Layout_ImageInfo *FirstSelected();
+	virtual Layout_ImageInfo *NextSelected();
 	Layout_Poster_ImageInfo *ImageAt(int page);
 	void DrawPreview(GtkWidget *widget,int xpos,int ypos,int width,int height);
 	virtual void (*SetUnitFunc())(GtkWidget *wid,enum Units unit);
