@@ -55,24 +55,24 @@ void Layout_Single_ImageInfo::Init()
 	delete is;
 	
 	l->GetImageableArea();
-	int sw=int((image_width*72.0)/native_xres);
-	int sh=int((image_height*72.0)/native_yres);
+	float sw=(image_width*72.0)/native_xres;
+	float sh=(image_height*72.0)/native_yres;
 	int mm=(l->imageablewidth>l->imageableheight);
 	mm^=image_width>image_height;
 	if(mm)
 	{
 		rotation=PP_ROTATION_90;
-		sw=int((image_height*72.0)/native_yres);
-		sh=int((image_width*72.0)/native_xres);
+		sw=(image_height*72.0)/native_yres;
+		sh=(image_width*72.0)/native_xres;
 	}
 	else
 		rotation=PP_ROTATION_NONE;
-	int s=100;
-	int s2=100;
+	float s=100.0;
+	float s2=100.0;
 	if(sw>l->imageablewidth)
-		s=(100*l->imageablewidth)/sw;
+		s=(100.0*l->imageablewidth)/sw;
 	if(sh>l->imageableheight)
-		s2=(100*l->imageableheight)/sh;
+		s2=(100.0*l->imageableheight)/sh;
 
 	if(s2<s)
 		s=s2;
@@ -103,10 +103,9 @@ Layout_Single_ImageInfo::~Layout_Single_ImageInfo()
 
 void Layout_Single_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int width,int height)
 {
+	cerr << "Drawing thumbnail" << endl;
 	GdkPixbuf *thumbnail=GetThumbnail();
-	if(transformed)
-		g_object_unref(transformed);
-	transformed=NULL;
+	GdkPixbuf *transformed=NULL;
 
 	Layout_Single *l=(Layout_Single *)&layout;
 
@@ -179,6 +178,9 @@ void Layout_Single_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypos,
 		xpos+lm,ypos+tm,
 		w,h,
 		GDK_RGB_DITHER_NONE,0,0);
+
+	g_object_unref(transformed);
+	cerr << "Finished drawing" << endl;
 }
 
 
@@ -405,3 +407,29 @@ int Layout_Single::GetCapabilities()
 {
 	return(PPLAYOUT_ROTATE|PPLAYOUT_MASK|PPLAYOUT_EFFECTS|PPLAYOUT_PROFILE);
 }
+
+
+Layout_ImageInfo *Layout_Single::FirstSelected()
+{
+	Layout_ImageInfo *ii=FirstImage();
+	while(ii)
+	{
+		if(ii->page==currentpage)
+			return(ii);
+		ii=NextSelected();
+	}
+	return(NULL);
+}
+
+
+Layout_ImageInfo *Layout_Single::NextSelected()
+{
+	Layout_ImageInfo *ii=NextImage();
+	while(ii)
+	{
+		if(ii->page==currentpage)
+			return(ii);
+		ii=NextSelected();
+	}
+	return(NULL);
+}
