@@ -33,6 +33,8 @@ class Layout_Single : public Layout
 	virtual void RefreshWidget(GtkWidget *widget);
 	virtual ImageSource *GetImageSource(int page,CMColourDevice target=CM_COLOURDEVICE_PRINTER,CMTransformFactory *factory=NULL,int res=0);
 	void UpdatePageSize();
+	virtual Layout_ImageInfo *FirstSelected();
+	virtual Layout_ImageInfo *NextSelected();
 	Layout_Single_ImageInfo *ImageAt(int page);
 	virtual void (*SetUnitFunc())(GtkWidget *wid,enum Units unit);
 	friend class Layout_Single_ImageInfo;
@@ -51,8 +53,8 @@ class Layout_Single_ImageInfo : public Layout_ImageInfo
 	int image_height;
 	double native_xres;
 	double native_yres;
-	int hscale;
-	int vscale;
+	float hscale;
+	float vscale;
 	private:
 	void Init();
 	friend class Layout_Single;
