@@ -35,7 +35,7 @@
 #include "support/generaldialogs.h"
 
 #define DEFAULTPRESETVERSION 29
-#define CURRENTPRESETVERSION 34
+#define CURRENTPRESETVERSION 38
 
 using namespace std;
 
@@ -50,6 +50,7 @@ ConfigTemplate PhotoPrint_State::Template[]=
 	ConfigTemplate("Win_Y",int(0)),
 	ConfigTemplate("Win_W",int(0)),
 	ConfigTemplate("Win_H",int(0)),
+	ConfigTemplate("HighresPreviews",int(1)),
 	// Now obsolete, left in for compatibility with pre-0.3.0 preset files.
 	ConfigTemplate("DefaultRGBProfile",""),
 	ConfigTemplate("DefaultRGBProfileActive",int(0)),
@@ -140,13 +141,13 @@ void PhotoPrint_State::SetDefaultFilename()
 }
 
 
-void PhotoPrint_State::ParseFile()
+void PhotoPrint_State::ParseConfigFile()
 {
 	// Config files from newer than 0.2.9 will override this
 	SetInt("PresetVersion",29);
 
 	printer.Reset();
-	ConfigFile::ParseFile(filename);
+	ConfigFile::ParseConfigFile(filename);
 
 	// Code to update older config files goes here...
 	int v=FindInt("PresetVersion");
@@ -178,7 +179,7 @@ void PhotoPrint_State::ParseFile()
 }
 
 
-bool PhotoPrint_State::SaveFile()
+bool PhotoPrint_State::SaveConfigFile()
 {
 	// Ensure that saved preset have the current PresetVersion...
 	SetInt("PresetVersion",CURRENTPRESETVERSION);
@@ -187,13 +188,13 @@ bool PhotoPrint_State::SaveFile()
 
 	cerr << "Filename : " << filename << endl;
 
-	return(ConfigFile::SaveFile(filename));
+	return(ConfigFile::SaveConfigFile(filename));
 }
 
 
 bool PhotoPrint_State::NewLayout(Progress *p)
 {
-	char *type=layoutdb.FindString("LayoutType");
+	const char *type=layoutdb.FindString("LayoutType");
 
 	Layout *nl=NULL;
 
