@@ -17,8 +17,8 @@ class PhotoPrint_State : public ConfigFile, public ConfigDB
 	~PhotoPrint_State();
 	void SetFilename(const char *file);
 	void SetDefaultFilename();
-	void ParseFile();
-	bool SaveFile();
+	void ParseConfigFile();
+	bool SaveConfigFile();
 	bool NewLayout(Progress *p=NULL);
 	void SetUnits(enum Units unit);
 	enum Units GetUnits();
