@@ -284,9 +284,8 @@ pp_layout_carousel_pageview_expose( GtkWidget      *widget,
 
 	if (event->count > 0)
 		return FALSE;
-  
-	pageview = PP_LAYOUT_CAROUSEL_PAGEVIEW (widget);
 
+	pageview = PP_LAYOUT_CAROUSEL_PAGEVIEW (widget);
 		
 	pageview->height=widget->allocation.height;
 	pageview->width=(pageview->layout->pagewidth*pageview->height)/pageview->layout->pageheight;
@@ -332,13 +331,13 @@ pp_layout_carousel_pageview_button_press( GtkWidget      *widget,
 		       GdkEventButton *event )
 {
 	pp_Layout_Carousel_PageView *pageview;
-	
+
 	g_return_val_if_fail (widget != NULL, FALSE);
 	g_return_val_if_fail (PP_IS_PAGEVIEW (widget), FALSE);
 	g_return_val_if_fail (event != NULL, FALSE);
-	
+
 	pageview = PP_LAYOUT_CAROUSEL_PAGEVIEW (widget);
-	
+
 	int x=int(event->x-pageview->left);
 	int y=int(event->y-pageview->top);
 	bool shift=(event->state&GDK_SHIFT_MASK)!=0;
@@ -355,7 +354,7 @@ pp_layout_carousel_pageview_button_press( GtkWidget      *widget,
 			case 1:
 				if(!(shift||ctrl))
 				{
-						if(pageview->selected && pageview->selected->allowcropping)
+						if(pageview->selected)
 						{
 							pageview->dragging=true;
 							pageview->init_x=x;
@@ -363,7 +362,6 @@ pp_layout_carousel_pageview_button_press( GtkWidget      *widget,
 							pageview->init_hpan=pageview->selected->crop_hpan;
 							pageview->init_vpan=pageview->selected->crop_vpan;
 							gtk_grab_add(widget);
-							cerr << "Commencing drag..." << endl;
 						}
 						else
 							pageview->dragging=false;
@@ -461,7 +459,6 @@ pp_layout_carousel_pageview_motion_notify( GtkWidget      *widget,
 		ii->crop_vpan=LayoutRectangle_Alignment(vp);
 
 		pageview->layout->FlushPreview();
-		cerr << "Dragging: " << hp << ", " << vp << endl;
 
 		gtk_widget_queue_draw (GTK_WIDGET (pageview));
 	}
@@ -485,7 +482,6 @@ pp_layout_carousel_pageview_button_release( GtkWidget      *widget,
 		case 1:	if (event->button==1)
 			pageview->dragging=false;
 			gtk_grab_remove(widget);
-			cerr << "Ending drag..." << endl;
 			break;
 		default:
 			break;
