@@ -9,6 +9,7 @@
 #include "pp_sigcontrol.h"
 #include "support/progressbar.h"
 
+#include "pp_menu_image.h"
 #include "dialogs.h"
 
 #include "pp_layout_nup_pageview.h"
@@ -271,6 +272,7 @@ pp_layout_nup_pageview_size_allocate (GtkWidget     *widget,
 			      allocation->width, allocation->height);
 
     }
+	pageview->layout->FlushHRPreviews();
 }
 
 
