@@ -1,11 +1,11 @@
 #include <string.h>
 
 #include <gtk/gtkframe.h>
-#include <gtk/gtksizegroup.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkexpander.h>
 
 #include "stpui_widgets/stpui_combo.h"
 #include "stpui_widgets/dimension.h"
@@ -13,6 +13,7 @@
 #include "layout.h"
 #include "dialogs.h"
 #include "pp_pageextent.h"
+#include "pp_imagecontrol.h"
 #include "pp_layout_poster_pageview.h"
 #include "pp_layout_poster.h"
 
@@ -54,6 +55,7 @@ static void pe_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
 	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
 	l->TilesFromSize();
 	pp_layout_poster_refresh(lo);
 	pp_Layout_Poster_PageView *pv=PP_LAYOUT_POSTER_PAGEVIEW(lo->pageview);
@@ -62,10 +64,22 @@ static void pe_changed(GtkWidget *wid,gpointer *ob)
 }
 
 
+static void ic_changed(GtkWidget *wid,gpointer *ob)
+{
+	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
+	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
+	pp_Layout_Poster_PageView *pv=PP_LAYOUT_POSTER_PAGEVIEW(lo->pageview);
+	pp_layout_poster_pageview_refresh(PP_LAYOUT_POSTER_PAGEVIEW(pv));
+	g_signal_emit(G_OBJECT (ob),pp_layout_poster_signals[CHANGED_SIGNAL], 0);
+}
+
+
 static void posterwidth_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
 	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
 
 	l->posterwidth=int(dimension_get_pt(DIMENSION(lo->posterwidth)));
 	l->TilesFromSize();
@@ -77,6 +91,7 @@ static void posterheight_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
 	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
 
 	l->posterheight=int(dimension_get_pt(DIMENSION(lo->posterheight)));
 	l->TilesFromSize();
@@ -88,6 +103,7 @@ static void htiles_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
 	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
 	
 	l->htiles=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(lo->htiles));
 	l->SizeFromTiles();
@@ -99,6 +115,7 @@ static void vtiles_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
 	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
 
 	cerr << "In VTiles_Changed" << endl;
 
@@ -112,6 +129,7 @@ static void hoverlap_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
 	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
 
 	l->hoverlap=int(dimension_get_pt(DIMENSION(lo->hoverlap)));
 	l->TilesFromSize();
@@ -123,6 +141,7 @@ static void voverlap_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Poster *lo=(pp_Layout_Poster *)ob;
 	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->FlushHRPreviews();
 
 	l->voverlap=int(dimension_get_pt(DIMENSION(lo->voverlap)));
 	l->TilesFromSize();
@@ -136,7 +155,12 @@ static void page_changed(GtkWidget *wid,gpointer *ob)
 	pp_Layout_Poster_PageView *pv=PP_LAYOUT_POSTER_PAGEVIEW(lo->pageview);
 	int pagesperposter=pv->layout->htiles*pv->layout->vtiles;
 
+	Layout_Poster *l=(Layout_Poster*)lo->state->layout;
+	l->CancelRenderThreads();
+
 	pp_layout_poster_pageview_set_page(pv,pagesperposter*(gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(lo->page))-1));
+
+	pp_imagecontrol_refresh(PP_IMAGECONTROL(lo->imagecontrol));
 	g_signal_emit(G_OBJECT (lo),pp_layout_poster_signals[CHANGED_SIGNAL], 0);
 }
 
@@ -233,13 +257,11 @@ pp_layout_poster_new (PhotoPrint_State *state)
 	ob->state=state;
 	
 	GtkWidget *vbox;
-	GtkWidget *vbox2;
 	GtkWidget *hbox;
 	GtkWidget *label;
-	GtkWidget *tmp;
 
-	ob->sizegroup = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-	
+	enum Units unit=state->GetUnits();
+
 	GtkWidget *frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 	gtk_box_pack_start(GTK_BOX (&ob->hbox), frame,TRUE,TRUE,0);
@@ -253,93 +275,190 @@ pp_layout_poster_new (PhotoPrint_State *state)
 	gtk_container_add (GTK_CONTAINER (frame), ob->pageview);
 	gtk_widget_show (ob->pageview);
 
+
+	// Scroll Window
+
 	GtkWidget *scrollwin=gtk_scrolled_window_new(NULL,NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+
 	vbox = gtk_vbox_new (FALSE, 5);
-	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), vbox);
-	gtk_box_pack_start(GTK_BOX(&ob->hbox),scrollwin,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(&ob->hbox),vbox,FALSE,FALSE,0);
 	gtk_widget_show (vbox);
+	gtk_box_pack_start(GTK_BOX(vbox),scrollwin,TRUE,TRUE,0);
 	gtk_widget_show (scrollwin);
 
-	enum Units unit=state->GetUnits();
-
-#define PP_BUILDDIMENSION(spinlabel,var,min,max,unit,callback) \
-	hbox=gtk_hbox_new(FALSE,0); \
-\
-	label=gtk_label_new(spinlabel); \
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5); \
-	gtk_widget_show(label); \
-\
-	var=dimension_new(min,max,unit); \
-	g_signal_connect(G_OBJECT(var),"value-changed",G_CALLBACK(callback),ob); \
-	gtk_widget_show(var); \
-\
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),var); \
-	gtk_box_pack_start(GTK_BOX(hbox),var,FALSE,FALSE,5); \
-\
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5); \
-	gtk_widget_show(hbox)
-
-#define PP_BUILDSPIN(spinlabel,var,min,max,step,callback) \
-	hbox=gtk_hbox_new(FALSE,0); \
-\
-	label=gtk_label_new(spinlabel); \
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5); \
-	gtk_widget_show(label); \
-\
-	var=gtk_spin_button_new_with_range(min,max,step); \
-	g_signal_connect(G_OBJECT(var),"value-changed",G_CALLBACK(callback),ob); \
-	gtk_widget_show(var); \
-\
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),var); \
-	gtk_box_pack_start(GTK_BOX(hbox),var,FALSE,FALSE,5); \
-\
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5); \
-	gtk_widget_show(hbox)
-
-#define PP_BUILDFRAME(framelabel) \
-	frame=gtk_frame_new(framelabel); \
-	gtk_box_pack_start(GTK_BOX(vbox),frame,FALSE,FALSE,0); \
-	gtk_container_set_border_width(GTK_CONTAINER(frame),5); \
-	gtk_widget_show(frame); \
-\
-	vbox2=gtk_vbox_new(FALSE,0); \
-	gtk_container_add(GTK_CONTAINER(frame),vbox2); \
-	gtk_widget_show(vbox2)
-
-
-	// PosterSize
-	PP_BUILDFRAME(_("Poster Size:"));
-	PP_BUILDDIMENSION(_("Width:"),ob->posterwidth,350,10000,unit,posterwidth_changed);
-	PP_BUILDDIMENSION(_("Height:"),ob->posterheight,350,10000,unit,posterheight_changed);
-	PP_BUILDSPIN(_("Tiles wide:"),ob->htiles,1,10,1,htiles_changed);
-	PP_BUILDSPIN(_("Tiles high:"),ob->vtiles,1,10,1,vtiles_changed);
-
-	PP_BUILDFRAME(_("Overlap:"));
-	PP_BUILDDIMENSION(_("H:"),ob->hoverlap,0,72,unit,hoverlap_changed);
-	PP_BUILDDIMENSION(_("V:"),ob->voverlap,0,72,unit,voverlap_changed);
-
-
-	// PageExtent
-
-	ob->pageextent=pp_pageextent_new((Layout_Poster *)ob->state->layout,ob->state,ob->sizegroup);
-	g_signal_connect(G_OBJECT(ob->pageextent),"changed",G_CALLBACK(pe_changed),ob);
-	gtk_box_pack_start(GTK_BOX(vbox),ob->pageextent,FALSE,FALSE,0);
-	gtk_widget_show(ob->pageextent);
-
-
-	// Spacer box
-
-	tmp=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),tmp,TRUE,TRUE,0);
-	gtk_widget_show(tmp);
-
 
 	// Page number
 
 	hbox=gtk_hbox_new(FALSE,5);
 	label=gtk_label_new(_("Page:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
+	gtk_widget_show(label);
+
+	ob->page=gtk_spin_button_new_with_range(1.0,2.0,1.0);
+	g_signal_connect(G_OBJECT(ob->page),"value-changed",G_CALLBACK(page_changed),ob);
+	gtk_widget_show(ob->page);
+
+	gtk_box_pack_start(GTK_BOX(hbox),ob->page,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
+	gtk_widget_show(hbox);
+
+
+	// Contents of scrollwindow
+
+	GtkWidget *hbox2=gtk_hbox_new(FALSE,0);
+	gtk_widget_show (hbox2);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox2),vbox,TRUE,TRUE,5);
+	
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), hbox2);
+//	gtk_container_foreach(GTK_CONTAINER(scrollwin),killshadow,NULL);
+	gtk_widget_show (vbox);
+
+#if 0
+
+	GtkWidget *scrollwin=gtk_scrolled_window_new(NULL,NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
+                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	GtkWidget *hbox2=gtk_hbox_new(FALSE,0);
+	gtk_widget_show (hbox2);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox2),vbox,TRUE,TRUE,5);
+	
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), hbox2);
+	gtk_box_pack_start(GTK_BOX(&ob->hbox),scrollwin,FALSE,FALSE,0);
+	gtk_widget_show (vbox);
+	gtk_widget_show (scrollwin);
+#endif
+
+	// PosterSize
+	frame=gtk_expander_new(_("Poster Layout"));
+	gtk_expander_set_expanded(GTK_EXPANDER(frame),true);
+	gtk_box_pack_start(GTK_BOX(vbox),frame,FALSE,FALSE,0);
+	gtk_widget_show(frame);
+
+	GtkWidget *table=gtk_table_new(4,2,false);
+	gtk_table_set_row_spacing(GTK_TABLE(table),0,5);
+	gtk_table_set_row_spacing(GTK_TABLE(table),2,3);
+	gtk_table_set_col_spacings(GTK_TABLE(table),3);
+	gtk_container_add(GTK_CONTAINER(frame),table);
+	gtk_widget_show(table);
+
+	// Width
+	
+	label=gtk_label_new(_("Size"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),0,1,0,1);
+	gtk_widget_show(label);
+
+	ob->posterwidth=dimension_new(350,10000,unit);
+	g_signal_connect(G_OBJECT(ob->posterwidth),"value-changed",G_CALLBACK(posterwidth_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->posterwidth),1,2,0,1);
+	gtk_widget_show(ob->posterwidth);
+
+	// Height
+
+	label=gtk_label_new(_("by"));
+	gtk_misc_set_alignment(GTK_MISC(label),0.5,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),2,3,0,1);
+	gtk_widget_show(label);
+
+	ob->posterheight=dimension_new(350,10000,unit);
+	g_signal_connect(G_OBJECT(ob->posterheight),"value-changed",G_CALLBACK(posterheight_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->posterheight),3,4,0,1);
+	gtk_widget_show(ob->posterheight);
+
+	// Tiles - H
+	
+	label=gtk_label_new(_("Tiles"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),0,1,1,2);
+	gtk_widget_show(label);
+
+	ob->htiles=gtk_spin_button_new_with_range(1,10,1);
+	g_signal_connect(G_OBJECT(ob->htiles),"value-changed",G_CALLBACK(htiles_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->htiles),1,2,1,2);
+	gtk_widget_show(ob->htiles);
+
+	// Height
+
+	label=gtk_label_new(_("by"));
+	gtk_misc_set_alignment(GTK_MISC(label),0.5,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),2,3,1,2);
+	gtk_widget_show(label);
+
+	ob->vtiles=gtk_spin_button_new_with_range(1,10,1);
+	g_signal_connect(G_OBJECT(ob->vtiles),"value-changed",G_CALLBACK(vtiles_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->vtiles),3,4,1,2);
+	gtk_widget_show(ob->vtiles);
+
+	frame=gtk_expander_new(_("Overlap"));
+	gtk_expander_set_expanded(GTK_EXPANDER(frame),true);
+	gtk_box_pack_start(GTK_BOX(vbox),frame,FALSE,FALSE,0);
+	gtk_widget_show(frame);
+
+	table=gtk_table_new(4,1,false);
+	gtk_table_set_row_spacings(GTK_TABLE(table),3);
+	gtk_table_set_col_spacings(GTK_TABLE(table),3);
+	gtk_container_add(GTK_CONTAINER(frame),table);
+	gtk_widget_show(table);
+
+	// HOverlap
+	
+	label=gtk_label_new(_("H:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),0,1,0,1);
+	gtk_widget_show(label);
+
+	ob->hoverlap=dimension_new(0,72,unit);
+	g_signal_connect(G_OBJECT(ob->hoverlap),"value-changed",G_CALLBACK(hoverlap_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->hoverlap),1,2,0,1);
+	gtk_widget_show(ob->hoverlap);
+
+	// VOverlap
+
+	label=gtk_label_new(_("V:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),2,3,0,1);
+	gtk_widget_show(label);
+
+	ob->voverlap=dimension_new(0,72,unit);
+	g_signal_connect(G_OBJECT(ob->voverlap),"value-changed",G_CALLBACK(voverlap_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->voverlap),3,4,0,1);
+	gtk_widget_show(ob->voverlap);
+
+
+	// PageExtent
+
+	ob->pageextent=pp_pageextent_new((Layout_Poster *)ob->state->layout,ob->state);
+	g_signal_connect(G_OBJECT(ob->pageextent),"changed",G_CALLBACK(pe_changed),ob);
+	gtk_box_pack_start(GTK_BOX(vbox),ob->pageextent,FALSE,FALSE,0);
+	gtk_widget_show(ob->pageextent);
+
+
+#if 0
+	// Spacer box
+
+	tmp=gtk_vbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),tmp,TRUE,TRUE,0);
+	gtk_widget_show(tmp);
+#endif
+
+	// ImageControl
+
+	ob->imagecontrol=pp_imagecontrol_new(ob->state->layout);
+	gtk_box_pack_start(GTK_BOX(vbox),ob->imagecontrol,TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(ob->imagecontrol),"changed",G_CALLBACK(ic_changed),ob);
+	gtk_widget_show(ob->imagecontrol);
+
+#if 0
+	// Page number
+
+	hbox=gtk_hbox_new(FALSE,5);
+	label=gtk_label_new(_("Page:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
 	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
 	gtk_widget_show(label);
 
@@ -352,9 +471,7 @@ pp_layout_poster_new (PhotoPrint_State *state)
 
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_widget_show(hbox);
-
-	g_object_unref(G_OBJECT(ob->sizegroup));
-	ob->sizegroup=NULL;
+#endif
 
 	pp_layout_poster_refresh(ob);
 	pp_pageextent_refresh(PP_PAGEEXTENT(ob->pageextent));
@@ -420,4 +537,5 @@ pp_layout_poster_init (pp_Layout_Poster *ob)
 {
 	ob->state=NULL;
 	ob->pageview=NULL;
+	ob->imagecontrol=NULL;
 }
