@@ -6,12 +6,14 @@
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkexpander.h>
 
 #include "stpui_widgets/stpui_combo.h"
 #include "support/tiffsave.h"
 #include "layout.h"
 #include "dialogs.h"
 #include "pp_pageextent.h"
+#include "pp_imagecontrol.h"
 #include "pp_layout_single_pageview.h"
 #include "pp_layout_single.h"
 
@@ -56,18 +58,27 @@ static void pe_changed(GtkWidget *wid,gpointer *ob)
 }
 
 
+static void ic_changed(GtkWidget *wid,gpointer *ob)
+{
+	pp_Layout_Single *lo=(pp_Layout_Single *)ob;
+	pp_Layout_Single_PageView *pv=PP_LAYOUT_SINGLE_PAGEVIEW(lo->pageview);
+	pp_layout_single_pageview_refresh(PP_LAYOUT_SINGLE_PAGEVIEW(pv));
+	g_signal_emit(G_OBJECT (ob),pp_layout_single_signals[CHANGED_SIGNAL], 0);
+}
+
+
 static void hscale_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Single *lo=(pp_Layout_Single *)ob;
 
-	int hs=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(lo->hscale));
+	float hs=gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(lo->hscale));
 	Layout_Single *l=(Layout_Single *)lo->state->layout;
 	int page=l->GetCurrentPage();
 	Layout_Single_ImageInfo *ii=l->ImageAt(page);
 
 	if(ii)
 	{
-		if(hs>=10 && hs<=1000)
+		if(hs>=10.0 && hs<=1000.0)
 			ii->hscale=hs;
 	}
 
@@ -79,14 +90,14 @@ static void vscale_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Single *lo=(pp_Layout_Single *)ob;
 
-	int vs=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(lo->vscale));
+	float vs=gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(lo->vscale));
 	Layout_Single *l=(Layout_Single *)lo->state->layout;
 	int page=l->GetCurrentPage();
 	Layout_Single_ImageInfo *ii=l->ImageAt(page);
 
 	if(ii)
 	{
-		if(vs>=10 && vs<=1000)
+		if(vs>=10.0 && vs<=1000.0)
 			ii->vscale=vs;	
 	}
 
@@ -153,6 +164,8 @@ void pp_layout_single_refresh(pp_Layout_Single *ob)
 	if(pv)
 		pp_layout_single_pageview_refresh(pv);
 
+	pp_imagecontrol_refresh(PP_IMAGECONTROL(ob->imagecontrol));
+
 	pp_pageextent_refresh(PP_PAGEEXTENT(ob->pageextent));
 }
 
@@ -174,13 +187,9 @@ pp_layout_single_new (PhotoPrint_State *state)
 	ob->state=state;
 	
 	GtkWidget *vbox;
-	GtkWidget *vbox2;
 	GtkWidget *hbox;
 	GtkWidget *label;
-	GtkWidget *tmp;
 
-	ob->sizegroup = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-	
 	GtkWidget *frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 	gtk_box_pack_start(GTK_BOX (&ob->hbox), frame,TRUE,TRUE,0);
@@ -195,75 +204,126 @@ pp_layout_single_new (PhotoPrint_State *state)
 	gtk_container_add (GTK_CONTAINER (frame), ob->pageview);
 	gtk_widget_show (ob->pageview);
 
+
+	// Scroll Window
+
 	GtkWidget *scrollwin=gtk_scrolled_window_new(NULL,NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+
 	vbox = gtk_vbox_new (FALSE, 5);
-	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), vbox);
-	gtk_box_pack_start(GTK_BOX(&ob->hbox),scrollwin,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(&ob->hbox),vbox,FALSE,FALSE,0);
 	gtk_widget_show (vbox);
+	gtk_box_pack_start(GTK_BOX(vbox),scrollwin,TRUE,TRUE,0);
 	gtk_widget_show (scrollwin);
 
 
-	// Scale
+	// Page number
+
+	hbox=gtk_hbox_new(FALSE,5);
+	label=gtk_label_new(_("Page:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
+	gtk_widget_show(label);
+
+	ob->page=gtk_spin_button_new_with_range(1.0,2.0,1.0);
+	g_signal_connect(G_OBJECT(ob->page),"value-changed",G_CALLBACK(page_changed),ob);
+	gtk_widget_show(ob->page);
+
+	gtk_box_pack_start(GTK_BOX(hbox),ob->page,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
+	gtk_widget_show(hbox);
+
+
+	// Contents of scrollwindow
+
+	GtkWidget *hbox2=gtk_hbox_new(FALSE,0);
+	gtk_widget_show (hbox2);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox2),vbox,TRUE,TRUE,5);
 	
-	frame=gtk_frame_new(_("Scale"));
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), hbox2);
+//	gtk_container_foreach(GTK_CONTAINER(scrollwin),killshadow,NULL);
+	gtk_widget_show (vbox);
+
+#if 0
+
+	GtkWidget *scrollwin=gtk_scrolled_window_new(NULL,NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
+                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	GtkWidget *hbox2=gtk_hbox_new(FALSE,0);
+	gtk_widget_show (hbox2);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox2),vbox,TRUE,TRUE,5);
+	
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), hbox2);
+	gtk_box_pack_start(GTK_BOX(&ob->hbox),scrollwin,FALSE,FALSE,0);
+	gtk_widget_show (vbox);
+	gtk_widget_show (scrollwin);
+#endif
+
+
+	// Scale
+
+	frame=gtk_expander_new(_("Manual scaling"));
+	gtk_expander_set_expanded(GTK_EXPANDER(frame),true);
 	gtk_box_pack_start(GTK_BOX(vbox),frame,FALSE,FALSE,0);
-	gtk_container_set_border_width(GTK_CONTAINER(frame),5);
 	gtk_widget_show(frame);
 
-	vbox2=gtk_vbox_new(FALSE,0);
-	gtk_container_add(GTK_CONTAINER(frame),vbox2);
-	gtk_widget_show(vbox2);
+	GtkWidget *table=gtk_table_new(4,2,false);
+	gtk_table_set_row_spacing(GTK_TABLE(table),0,5);
+	gtk_table_set_row_spacing(GTK_TABLE(table),2,3);
+	gtk_table_set_col_spacings(GTK_TABLE(table),3);
+	gtk_container_add(GTK_CONTAINER(frame),table);
+	gtk_widget_show(table);
 
 
 	//    HScale spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
-	
 	label=gtk_label_new(_("H (%):"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
 	gtk_widget_show(label);
 
-	ob->hscale=gtk_spin_button_new_with_range(10.0,1000.0,1.0);
+	ob->hscale=gtk_spin_button_new_with_range(10.0,1000.0,0.1);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(ob->hscale),100);
 	g_signal_connect(G_OBJECT(ob->hscale),"value-changed",G_CALLBACK(hscale_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),ob->hscale,1,2,0,1);
 	gtk_widget_show(ob->hscale);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),ob->hscale);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->hscale,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
-
 	
 	//    VScale spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
-	
 	label=gtk_label_new(_("V (%):"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
 	gtk_widget_show(label);
 
-	ob->vscale=gtk_spin_button_new_with_range(10.0,1000.0,1.0);
+	ob->vscale=gtk_spin_button_new_with_range(10.0,1000.0,0.1);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(ob->vscale),100);
 	g_signal_connect(G_OBJECT(ob->vscale),"value-changed",G_CALLBACK(vscale_changed),ob);
+	gtk_table_attach_defaults(GTK_TABLE(table),ob->vscale,1,2,1,2);
 	gtk_widget_show(ob->vscale);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),ob->vscale);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->vscale,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
 
 	// PageExtent
 
-	ob->pageextent=pp_pageextent_new((Layout_Single *)ob->state->layout,ob->state,ob->sizegroup);
+	ob->pageextent=pp_pageextent_new((Layout_Single *)ob->state->layout,ob->state);
 	g_signal_connect(G_OBJECT(ob->pageextent),"changed",G_CALLBACK(pe_changed),ob);
 	gtk_box_pack_start(GTK_BOX(vbox),ob->pageextent,FALSE,FALSE,0);
 	gtk_widget_show(ob->pageextent);
 
 
+	// ImageControl
+
+	ob->imagecontrol=pp_imagecontrol_new(ob->state->layout);
+	gtk_box_pack_start(GTK_BOX(vbox),ob->imagecontrol,TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(ob->imagecontrol),"changed",G_CALLBACK(ic_changed),ob);
+	gtk_widget_show(ob->imagecontrol);
+
+
+
+#if 0
 	// Spacer box
 
 	tmp=gtk_vbox_new(FALSE,0);
@@ -275,6 +335,7 @@ pp_layout_single_new (PhotoPrint_State *state)
 
 	hbox=gtk_hbox_new(FALSE,5);
 	label=gtk_label_new(_("Page:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
 	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
 	gtk_widget_show(label);
 
@@ -287,9 +348,7 @@ pp_layout_single_new (PhotoPrint_State *state)
 
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_widget_show(hbox);
-
-	g_object_unref(G_OBJECT(ob->sizegroup));
-	ob->sizegroup=NULL;
+#endif
 
 	pp_layout_single_refresh(ob);
 
@@ -354,4 +413,5 @@ pp_layout_single_init (pp_Layout_Single *ob)
 {
 	ob->state=NULL;
 	ob->pageview=NULL;
+	ob->imagecontrol=NULL;
 }
