@@ -51,19 +51,6 @@ static void layout_changed(GtkWidget *wid,gpointer *ob);
 // Functions invoked from the menus:
 
 
-static void savegeometry(pp_MainWindow *mw)
-{
-	gint x,y,w,h;
-	gtk_window_get_position(GTK_WINDOW(mw),&x,&y);
-	gtk_window_get_size(GTK_WINDOW(mw),&w,&h);
-
-	mw->state->SetInt("Win_X",x);
-	mw->state->SetInt("Win_Y",y);
-	mw->state->SetInt("Win_W",w);
-	mw->state->SetInt("Win_H",h);
-}
-
-
 static void layout_selection_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_MainWindow *mw=(pp_MainWindow *)ob;
@@ -112,7 +99,6 @@ static void layout_changed(GtkWidget *wid,gpointer *ob)
 
 void pp_mainwindow_refresh(pp_MainWindow *ob)
 {
-	cerr << "Refreshing window" << endl;
 	if(ob->layout)
 		ob->state->layout->RefreshWidget(ob->layout);
 
@@ -176,6 +162,10 @@ pp_mainwindow_new (PhotoPrint_State *state)
 
 	int caps=ob->state->layout->GetCapabilities();
 	ImageMenu_SetLayoutCapabilities(ob->uim,caps);
+	LayoutMenu_SetLayoutCapabilities(ob->uim,caps);
+
+	OptionsMenu_SetHighresPreviews(ob->uim,state->FindInt("HighresPreviews"));
+	OptionsMenu_SetProofMode(ob->uim,CMProofMode(state->profilemanager.FindInt("ProofMode")));
 
 	pp_mainwindow_refresh(ob);
 
@@ -251,6 +241,10 @@ void pp_mainwindow_rebuild(pp_MainWindow *mw)
 		}
 		int caps=mw->state->layout->GetCapabilities();
 		ImageMenu_SetLayoutCapabilities(mw->uim,caps);
+		LayoutMenu_SetLayoutCapabilities(mw->uim,caps);
+
+		OptionsMenu_SetHighresPreviews(mw->uim,mw->state->FindInt("HighresPreviews"));
+		OptionsMenu_SetProofMode(mw->uim,CMProofMode(mw->state->profilemanager.FindInt("ProofMode")));
 
 		pp_mainwindow_refresh(mw);
 	}
