@@ -122,7 +122,7 @@ static GtkActionEntry layoutmenu_entries[] = {
   { "LayoutMenu", NULL, N_("_Layout") },
   
   { "ClearLayout", NULL, N_("_Clear Layout"), "<control>K", N_("Remove all images from the layout"), G_CALLBACK(layoutmenu_clearlayout) },
-  { "Set Background", NULL, N_("Set _Background"), "<control>B", N_("Set a background image for the current layout"), G_CALLBACK(layoutmenu_setbackground) },
+  { "SetBackground", NULL, N_("Set _Background"), "<control>B", N_("Set a background image for the current layout"), G_CALLBACK(layoutmenu_setbackground) },
 };
 
 
@@ -139,7 +139,7 @@ static const char *layoutmenu_ui_description =
 "  <menubar name='MainMenu'>"
 "    <menu action='LayoutMenu'>"
 "      <menuitem action='ClearLayout'/>"
-"      <menuitem action='Set Background'/>"
+"      <menuitem action='SetBackground'/>"
 "      <separator/>"
 "      <menuitem action='AutoLayout'/>"
 "      <menuitem action='Poster'/>"
@@ -177,8 +177,6 @@ void LayoutMenu_SetLayout(GtkUIManager *ui_manager,const char *layouttype)
 	if(strcmp(layouttype,"Carousel")==0)
 		item=LAYOUT_CAROUSEL;
 
-	cerr << "Setting layout radio option to... " << item << endl;
-
 #if 0
 	GtkAction *act=gtk_ui_manager_get_action(ui_manager,"/MainMenu/LayoutMenu/AutoLayout");
 	if(act)
@@ -200,8 +198,32 @@ void LayoutMenu_SetLayout(GtkUIManager *ui_manager,const char *layouttype)
 		w=gtk_ui_manager_get_widget(ui_manager,menupaths[i]);
 		if(w)
 		{
-			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(w),i==item);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(w),(enum LAYOUTRADIOOPTIONS)i==item);
 		}
 	}
 #endif
 }
+
+
+void LayoutMenu_SetLayoutCapabilities(GtkUIManager *ui_manager,int features)
+{
+	struct menucapentry
+	{
+		const char *path;
+		int flag;
+	};
+	
+	menucapentry tags[]={
+		{"/MainMenu/LayoutMenu/SetBackground",PPLAYOUT_BACKGROUND},
+		{NULL,0}
+	};
+
+	menucapentry *p=&tags[0];
+	while(p->flag)
+	{
+		GtkWidget *w=gtk_ui_manager_get_widget(ui_manager,p->path);
+		if(w)
+			gtk_widget_set_sensitive(w,(features&p->flag)!=0);
+		++p;
+	}
+}
