@@ -6,6 +6,7 @@
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkhbox.h>
+#include <gtk/gtkexpander.h>
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtksizegroup.h>
 
@@ -28,30 +29,31 @@ class PhotoPrint_State;
 
 struct _pp_PageExtent
 {
-	GtkVBox	box;
+	GtkExpander	box;
 	GtkWidget *lmargin;
 	GtkWidget *rmargin;
 	GtkWidget *tmargin;
 	GtkWidget *bmargin;
 	GtkWidget *pagesize;
 	GtkWidget *customwidth;
-	GtkWidget *customwidthhbox;
+	GtkWidget *customwidthlabel;
 	GtkWidget *customheight;
-	GtkWidget *customheighthbox;
+	GtkWidget *customheightlabel;
 	PageExtent *pe;
 	PhotoPrint_State *state;
+	bool blocksignals;
 };
 
 
 struct _pp_PageExtentClass
 {
-	GtkVBoxClass parent_class;
+	GtkExpanderClass parent_class;
 
 	void (*changed)(pp_PageExtent *sig);
 };
 
 GType pp_pageextent_get_type (void);
-GtkWidget* pp_pageextent_new (PageExtent *pe,PhotoPrint_State *state,GtkSizeGroup *sizegroup);
+GtkWidget* pp_pageextent_new (PageExtent *pe,PhotoPrint_State *state);
 void pp_pageextent_refresh(pp_PageExtent *ob);
 void pp_pageextent_set_unit(pp_PageExtent *ob,enum Units unit);
 G_END_DECLS
