@@ -1,6 +1,7 @@
 #include <string.h>
 
 #include <gtk/gtkframe.h>
+#include <gtk/gtkexpander.h>
 #include <gtk/gtksizegroup.h>
 #include <gtk/gtklabel.h>
 
@@ -33,6 +34,7 @@ static void rows_changed(GtkWidget *wid,gpointer *ob)
 	GtkSpinButton *spin=GTK_SPIN_BUTTON(wid);
 	int v=gtk_spin_button_get_value_as_int(spin);
 	sig->SetRows(v);
+	g_signal_emit(G_OBJECT (ob),pp_sigcontrol_signals[CHANGED_SIGNAL], 0);
 	g_signal_emit(G_OBJECT (ob),pp_sigcontrol_signals[REFLOW_SIGNAL], 0);
 }
 
@@ -44,6 +46,7 @@ static void cols_changed(GtkWidget *wid,gpointer *ob)
 	GtkSpinButton *spin=GTK_SPIN_BUTTON(wid);
 	int v=gtk_spin_button_get_value_as_int(spin);
 	sig->SetColumns(v);
+	g_signal_emit(G_OBJECT (ob),pp_sigcontrol_signals[CHANGED_SIGNAL], 0);
 	g_signal_emit(G_OBJECT (ob),pp_sigcontrol_signals[REFLOW_SIGNAL], 0);
 }
 
@@ -86,37 +89,32 @@ void pp_sigcontrol_set_unit(pp_SigControl *ob,enum Units unit)
 
 
 GtkWidget*
-pp_sigcontrol_new (Signature *sig,GtkSizeGroup *sizegroup,enum Units unit)
+pp_sigcontrol_new (Signature *sig,enum Units unit)
 {
 	pp_SigControl *ob=PP_SIGCONTROL(g_object_new (pp_sigcontrol_get_type (), NULL));
-	gtk_box_set_spacing(GTK_BOX(ob),5);
+//	gtk_box_set_spacing(GTK_BOX(ob),5);
 
 	ob->sig=sig;
 	
-	GtkWidget *hbox;
 	GtkWidget *label;
-	GtkWidget *vbox;
-	GtkWidget *frame;
 
 
 	// Layout frame
 
 
-	frame=gtk_frame_new(_("Layout"));
-	gtk_box_pack_start(GTK_BOX(ob),frame,FALSE,FALSE,0);
-	gtk_container_set_border_width(GTK_CONTAINER(frame),5);
-	gtk_widget_show(frame);
-	
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_container_add(GTK_CONTAINER(frame),vbox);
-	gtk_widget_show(vbox);
+	gtk_expander_set_expanded(GTK_EXPANDER(ob),true);
+	gtk_expander_set_label(GTK_EXPANDER(ob),_("Layout"));
+
+	GtkWidget *table=gtk_table_new(4,2,false);
+	gtk_table_set_row_spacings(GTK_TABLE(table),5);
+
+	gtk_container_add(GTK_CONTAINER(ob),table);
 
 	//    Columns spin button
-
-	hbox=gtk_hbox_new(FALSE,0);
 	
 	label=gtk_label_new(_("Columns:"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),0,1,0,1);
 	gtk_widget_show(label);
 
 	ob->cols=gtk_spin_button_new_with_range(1.0,10.0,1.0);
@@ -124,17 +122,13 @@ pp_sigcontrol_new (Signature *sig,GtkSizeGroup *sizegroup,enum Units unit)
 	g_signal_connect(G_OBJECT(ob->cols),"value-changed",G_CALLBACK(cols_changed),ob);
 	gtk_widget_show(ob->cols);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(sizegroup),ob->cols);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->cols,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->cols),1,2,0,1);
 
 	//    Rows spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
 	label=gtk_label_new(_("Rows:"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),0,1,1,2);
 	gtk_widget_show(label);
 
 	ob->rows=gtk_spin_button_new_with_range(1.0,10.0,1.0);
@@ -142,60 +136,39 @@ pp_sigcontrol_new (Signature *sig,GtkSizeGroup *sizegroup,enum Units unit)
 	g_signal_connect(G_OBJECT(ob->rows),"value-changed",G_CALLBACK(rows_changed),ob);
 	gtk_widget_show(ob->rows);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(sizegroup),ob->rows);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->rows,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->rows),1,2,1,2);
 
 
 	// Gutters frame
 
-	frame=gtk_frame_new(_("Gutters"));
-	gtk_box_pack_start(GTK_BOX(ob),frame,FALSE,FALSE,0);
-	gtk_container_set_border_width(GTK_CONTAINER(frame),5);
-	gtk_widget_show(frame);
-
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_container_add(GTK_CONTAINER(frame),vbox);
-	gtk_widget_show(vbox);
-
 	//    HGutter spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
 	
-	label=gtk_label_new(_("Horizontal:"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	label=gtk_label_new(_("Gap:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),2,3,0,1);
 	gtk_widget_show(label);
 
 	ob->hgutter=dimension_new(0.0,200.0,unit);
 	g_signal_connect(G_OBJECT(ob->hgutter),"value-changed",G_CALLBACK(hgutter_changed),ob);
 	gtk_widget_show(ob->hgutter);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(sizegroup),ob->hgutter);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->hgutter,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->hgutter),3,4,0,1);
 
 	//    VGutter spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
-	
-	label=gtk_label_new(_("Vertical:"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	label=gtk_label_new(_("Gap:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(label),2,3,1,2);
 	gtk_widget_show(label);
 
 	ob->vgutter=dimension_new(0.0,200.0,unit);
 	g_signal_connect(G_OBJECT(ob->vgutter),"value-changed",G_CALLBACK(vgutter_changed),ob);
 	gtk_widget_show(ob->vgutter);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(sizegroup),ob->vgutter);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->vgutter,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),GTK_WIDGET(ob->vgutter),3,4,1,2);
 
+	gtk_widget_show(table);
 
 	pp_sigcontrol_refresh(ob);
 
@@ -222,7 +195,7 @@ pp_sigcontrol_get_type (void)
 			0,
 			(GInstanceInitFunc) pp_sigcontrol_init,
 		};
-		stpuic_type = g_type_register_static (GTK_TYPE_VBOX, "pp_SigControl", &pp_sigcontrol_info, (GTypeFlags)0);
+		stpuic_type = g_type_register_static (GTK_TYPE_EXPANDER, "pp_SigControl", &pp_sigcontrol_info, (GTypeFlags)0);
 	}
 	return stpuic_type;
 }
