@@ -4,6 +4,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkexpander.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkspinbutton.h>
@@ -28,7 +29,7 @@ struct Signature;
 
 struct _pp_SigControl
 {
-	GtkVBox	box;
+	GtkExpander box;
 	GtkWidget *rows;
 	GtkWidget *cols;
 	GtkWidget *hgutter;
@@ -39,14 +40,14 @@ struct _pp_SigControl
 
 struct _pp_SigControlClass
 {
-	GtkVBoxClass parent_class;
+	GtkExpanderClass parent_class;
 
 	void (*changed)(pp_SigControl *sig);
 	void (*reflow)(pp_SigControl *sig);
 };
 
 GType pp_sigcontrol_get_type (void);
-GtkWidget* pp_sigcontrol_new (Signature *sig,GtkSizeGroup *sizegroup,enum Units unit=UNIT_POINTS);
+GtkWidget* pp_sigcontrol_new (Signature *sig,enum Units unit=UNIT_POINTS);
 void pp_sigcontrol_refresh(pp_SigControl *ob);
 void pp_sigcontrol_set_unit(pp_SigControl *ob,enum Units unit);
 
