@@ -280,7 +280,13 @@ void GPrinter::Print(ImageSource *src,int xpos,int ypos)
 			throw "Only RGB and CMYK images are currently supported!";
 			break;
 	}
-	stp_set_string_parameter(stpvars, "PrintingMode", "Color");
+	cerr << "Checking PrintingMode:" << endl;
+	const char *pm=stp_get_string_parameter(stpvars,"PrintingMode");
+	if(pm)
+		cerr << "PrintingMode currently set to:" << pm << endl;
+	else
+		cerr << "PrintingMode currently not set." << endl;
+//	stp_set_string_parameter(stpvars, "PrintingMode", "Color");
 
 	this->xpos=xpos;
 	this->ypos=ypos;
