@@ -10,7 +10,7 @@
 class PrintOutput : public ConfigDB, public PrinterQueues
 {
 	public:
-	PrintOutput(ConfigFile *inif,char *section);
+	PrintOutput(ConfigFile *inif,const char *section);
 	Consumer *GetConsumer();
 	void DBToQueues();
 	void QueuesToDB();
