@@ -1,12 +1,20 @@
 #include <iostream>
 
-#ifndef WIN32
-#include <X11/Xlib.h>
+#ifdef WIN32
+#include <windows.h>
+#else
 #include <X11/Xatom.h>
 #endif
 
 #include "profilemanager.h"
-#include "../support/searchpathdbhandler.h"
+#include "searchpathdbhandler.h"
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "gettext.h"
+#define _(x) gettext(x)
 
 #define SYSTEMMONITORPROFILE_ESCAPESTRING "<System monitor profile>"
 
@@ -18,7 +26,7 @@ using namespace std;
 
 ConfigTemplate ProfileManager::Template[]=
 {
- 	ConfigTemplate("DefaultRGBProfile","sRGB Color Space Profile.icm"),
+ 	ConfigTemplate("DefaultRGBProfile","sRGB_IEC61966-2-1_noBPC.icc"),
 	ConfigTemplate("DefaultRGBProfileActive",int(1)),
 	ConfigTemplate("DefaultCMYKProfile","USWebCoatedSWOP.icc"),
 	ConfigTemplate("DefaultCMYKProfileActive",int(1)),
@@ -32,19 +40,26 @@ ConfigTemplate ProfileManager::Template[]=
 	ConfigTemplate("MonitorProfileActive",int(0)),
 	ConfigTemplate("RenderingIntent",int(LCMSWRAPPER_INTENT_PERCEPTUAL)),
 	ConfigTemplate("ProofMode",int(CM_PROOFMODE_NONE)),
+#ifdef WIN32
+	ConfigTemplate("ProfilePath","c:\\winnt\\system32\\spool\\drivers\\color\\;c:\\windows\\system32\\spool\\drivers\\color"),
+#else
 	ConfigTemplate("ProfilePath","/usr/share/color/icc:/usr/local/share/color/icc/:$HOME/.color/icc"),
-//	ConfigTemplate("ProfilePath",""),
+#endif
 	ConfigTemplate()
 };
 
 
 ProfileManager::ProfileManager(ConfigFile *inifile,const char *section) :
-	ConfigDB(Template), SearchPath(), first(NULL), proffromdisplay(NULL)
+	ConfigDB(Template), SearchPath(), first(NULL), proffromdisplay_size(0)
 {
+#ifndef WIN32
+	xdisplay = XOpenDisplay(NULL);
+ 	proffromdisplay=NULL;
+#endif
 	new SearchPathDBHandler(inifile,section,this,this,"ProfilePath");
 	AddPath(FindString("ProfilePath"));
 	GetProfileFromDisplay();
-	if(proffromdisplay)
+	if(proffromdisplay_size)
 		SetInt("MonitorProfileActive",1);
 }
 
@@ -54,33 +69,44 @@ ProfileManager::~ProfileManager()
 #ifndef WIN32
 	if(proffromdisplay)
 		XFree(proffromdisplay);
-#endif
 	proffromdisplay=NULL;
+	XCloseDisplay (xdisplay);
+#endif
+	ProfileInfo *pi;
+	while((pi=first))
+		delete first;
 }
 
 
 CMSProfile *ProfileManager::GetProfile(const char *name)
 {
 	CMSProfile *result=NULL;
-	char *fn=Search(name);
-
-	if(strcmp(name,SYSTEMMONITORPROFILE_ESCAPESTRING)==0 && proffromdisplay)
-		result=new CMSProfile((char *)proffromdisplay,proffromdisplay_size);
-
-	if(fn && strlen(fn))
+	if(name && strlen(name))
 	{
-		try
+		char *fn=Search(name);
+
+		if(strcmp(name,SYSTEMMONITORPROFILE_ESCAPESTRING)==0 && proffromdisplay_size)
+#ifdef WIN32	
+			result=new CMSProfile(displayprofilename);
+#else
+			result=new CMSProfile((char *)proffromdisplay,proffromdisplay_size);
+#endif
+
+		if(fn && strlen(fn))
 		{
-			result=new CMSProfile(fn);
+			try
+			{
+				result=new CMSProfile(fn);
+			}
+			catch(const char *err)
+			{
+				free(fn);
+				throw err;
+			}
 		}
-		catch(const char *err)
-		{
+		if(fn)
 			free(fn);
-			throw err;
-		}
 	}
-	if(fn)
-		free(fn);
 	return(result);
 }
 
@@ -119,7 +145,7 @@ CMSProfile *ProfileManager::GetProfile(enum CMColourDevice target)
 				profilename=FindString("DefaultCMYKProfile");
 			break;
 		default:
-			throw "Unknown target device!";
+			break;
 	}
 	if(profilename)
 		return(GetProfile(profilename));
@@ -145,6 +171,9 @@ CMSProfile *ProfileManager::GetDefaultProfile(IS_TYPE colourspace)
 			if(FindInt("DefaultCMYKProfileActive"))
 				profilename=FindString("DefaultCMYKProfile");
 			break;
+		default:
+			throw "Image colourspace not yet handled...";
+			break;
 	}
 	if(profilename)
 		return(GetProfile(profilename));
@@ -239,6 +268,7 @@ CMSTransform *CMTransformFactory::GetTransform(enum CMColourDevice target,IS_TYP
 
 CMSTransform *CMTransformFactory::GetTransform(enum CMColourDevice target,CMSProfile *srcprofile,LCMSWrapper_Intent intent)
 {
+	CMSTransform *result=NULL;
 	// If a NULL profile is supplied, we currently bail out.
 	// Theoretically we could continue if the target's profile is a DeviceLink,
 	// or we could assume a colourspace to match the target's profile,
@@ -255,26 +285,33 @@ CMSTransform *CMTransformFactory::GetTransform(enum CMColourDevice target,CMSPro
 		switch(manager.FindInt("ProofMode"))
 		{
 			case CM_PROOFMODE_NONE:
-				cerr << "Proofmode: None - using normal transform" << endl;
-				return(GetTransform(destprofile,srcprofile,intent));
+//				cerr << "Proofmode: None - using normal transform" << endl;
+				result=GetTransform(destprofile,srcprofile,intent);
 				break;
 			case CM_PROOFMODE_SIMULATEPRINT:
-				cerr << "Proofmode: Simulate Printer - using abs.col. proof transform" << endl;
+//				cerr << "Proofmode: Simulate Printer - using abs.col. proof transform" << endl;
 				proofprofile=manager.GetProfile(CM_COLOURDEVICE_PRINTER);
 				if(proofprofile)
-					return(GetTransform(destprofile,srcprofile,proofprofile,intent,LCMSWRAPPER_INTENT_ABSOLUTE_COLORIMETRIC));
+					result=GetTransform(destprofile,srcprofile,proofprofile,intent,LCMSWRAPPER_INTENT_ABSOLUTE_COLORIMETRIC);
 				break;
 			case CM_PROOFMODE_SIMULATEPRINTADAPTWHITE:
-				cerr << "Proofmode: Simulate Printer, Adapt White - using rel.col. proof transform" << endl;
+//				cerr << "Proofmode: Simulate Printer, Adapt White - using rel.col. proof transform" << endl;
 				proofprofile=manager.GetProfile(CM_COLOURDEVICE_PRINTER);
 				if(proofprofile)
-					return(GetTransform(destprofile,srcprofile,proofprofile,intent,LCMSWRAPPER_INTENT_RELATIVE_COLORIMETRIC));
+					result=GetTransform(destprofile,srcprofile,proofprofile,intent,LCMSWRAPPER_INTENT_RELATIVE_COLORIMETRIC);
 				break;
 			default:
 				break;
 		}
+		if(proofprofile)
+			delete proofprofile;
 	}
-	return(GetTransform(destprofile,srcprofile,intent));
+	else
+		result=GetTransform(destprofile,srcprofile,intent);
+
+	delete destprofile;
+
+	return(result);
 }
 
 
@@ -290,7 +327,7 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 	if(intent==LCMSWRAPPER_INTENT_DEFAULT)
 		intent=LCMSWRAPPER_INTENT_PERCEPTUAL;
 
-	cerr << "Using intent: " << intent << endl;
+//	cerr << "Using intent: " << intent << endl;
 
 	// We use MD5 digests to compare profiles for equality.
 	MD5Digest *d1,*d2;
@@ -298,7 +335,7 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 
 	if(destprofile->IsDeviceLink())
 	{
-		cerr << "Device link profile detected" << endl;
+//		cerr << "Device link profile detected" << endl;
 		// Device link profiles make life awkward if we have to use a source profile
 		// (which we must do in the case of an image having an embedded profile).
 		// What we do here is convert from the source profile to the appropriate
@@ -312,7 +349,7 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 		// create a multi-profile transform: src -> default -> devicelink.
 		if((srcprofile)&&(defprofile)&&(*srcprofile->GetMD5()!=*defprofile->GetMD5()))
 		{
-			cerr << "Source and default profiles don't match - building transform chain..." << endl;
+//			cerr << "Source and default profiles don't match - building transform chain..." << endl;
 			CMSProfile *profiles[3];
 			profiles[0]=srcprofile;
 			profiles[1]=defprofile;
@@ -323,21 +360,21 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 			transform=Search(d1,d2,intent);
 			if(!transform)
 			{
-				cerr << "No suitable cached transform found - creating a new one..." << endl;
+//				cerr << "No suitable cached transform found - creating a new one..." << endl;
 				transform=new CMSTransform(profiles,3,intent);
 				new CMTransformFactoryNode(this,transform,*d1,*d2,intent);
 			}
 		}
 		else
 		{
-			cerr << "Source and default profiles match - using devicelink in isolation..." << endl;
+//			cerr << "Source and default profiles match - using devicelink in isolation..." << endl;
 			// If there's no default profile, or the source and default profiles match
 			// then we can just use the devicelink profile in isolation.
 			d1=d2;
 			transform=Search(d1,d2,intent);
 			if(!transform)
 			{
-				cerr << "No suitable cached transform found - creating a new one..." << endl;
+//				cerr << "No suitable cached transform found - creating a new one..." << endl;
 				transform=new CMSTransform(destprofile,intent);
 				new CMTransformFactoryNode(this,transform,*d1,*d2,intent);
 			}
@@ -357,12 +394,11 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 		transform=Search(d1,d2,intent);
 		if(!transform)
 		{
-			cerr << "No suitable cached transform found - creating a new one..." << endl;
+//			cerr << "No suitable cached transform found - creating a new one..." << endl;
 			transform=new CMSTransform(srcprofile,destprofile,intent);
 			new CMTransformFactoryNode(this,transform,*d1,*d2,intent);
 		}
 	}
-	delete destprofile;
 
 	return(transform);
 }
@@ -370,12 +406,15 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 
 CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfile *srcprofile,CMSProfile *proofprofile,LCMSWrapper_Intent intent,int displayintent)
 {
-	cerr << "Getting proofing transform - Using intent: " << intent << endl;
+//	cerr << "Getting proofing transform - Using intent: " << intent << endl;
 
 	// No point whatever in continuing without an output device profile...
 	if(!destprofile)
 		return(NULL);
 
+	if(!proofprofile)
+		throw _("No Proof profile provided!");
+
 	CMSTransform *transform=NULL;
 	if(intent==LCMSWRAPPER_INTENT_DEFAULT)
 		intent=LCMSWrapper_Intent(manager.FindInt("RenderingIntent"));
@@ -385,7 +424,7 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 	if(displayintent==LCMSWRAPPER_INTENT_DEFAULT)
 		displayintent=LCMSWRAPPER_INTENT_ABSOLUTE_COLORIMETRIC;
 
-	cerr << "Using intent: " << intent << endl;
+//	cerr << "Using intent: " << intent << endl;
 
 	// We use MD5 digests to compare profiles for equality.
 	MD5Digest *d1,*d2;
@@ -393,7 +432,7 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 
 	if(destprofile->IsDeviceLink())
 	{
-		cerr << "Device link profile detected" << endl;
+//		cerr << "Device link profile detected" << endl;
 		// Device link profiles make life awkward if we have to use a source profile
 		// (which we must do in the case of an image having an embedded profile).
 		// What we do here is convert from the source profile to the appropriate
@@ -407,7 +446,7 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 		// create a multi-profile transform: src -> default -> devicelink.
 		if((srcprofile)&&(defprofile)&&(*srcprofile->GetMD5()!=*defprofile->GetMD5()))
 		{
-			cerr << "Source and default profiles don't match - building transform chain..." << endl;
+//			cerr << "Source and default profiles don't match - building transform chain..." << endl;
 			CMSProfile *profiles[3];
 			profiles[0]=srcprofile;
 			profiles[1]=defprofile;
@@ -418,8 +457,8 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 			transform=Search(d1,d2,intent,true);
 			if(!transform)
 			{
-				cerr << "No suitable cached transform found - creating a new one..." << endl;
-				cerr << "But can't (yet?) create embedded->default->devicelink->proof transform!" << endl;
+//				cerr << "No suitable cached transform found - creating a new one..." << endl;
+//				cerr << "But can't (yet?) create embedded->default->devicelink->proof transform!" << endl;
 				// FIXME - need a version of CMSProofingTransform that can cope with
 				// multiple profiles!
 				transform=new CMSTransform(profiles,3,intent);
@@ -428,14 +467,14 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 		}
 		else
 		{
-			cerr << "Source and default profiles match - using devicelink in isolation..." << endl;
+//			cerr << "Source and default profiles match - using devicelink in isolation..." << endl;
 			// If there's no default profile, or the source and default profiles match
 			// then we can just use the devicelink profile in isolation.
 			d1=d2;
 			transform=Search(d1,d2,intent,true);
 			if(!transform)
 			{
-				cerr << "No suitable cached transform found - creating a new one..." << endl;
+//				cerr << "No suitable cached transform found - creating a new one..." << endl;
 				// FIXME - need a version of CMSProofingTransform that can cope with
 				// devicelink profiles
 				transform=new CMSProofingTransform(destprofile,proofprofile,intent,displayintent);
@@ -458,12 +497,11 @@ CMSTransform *CMTransformFactory::GetTransform(CMSProfile *destprofile,CMSProfil
 		transform=Search(d1,d2,intent,true);
 		if(!transform)
 		{
-			cerr << "No suitable cached transform found - creating a new proofing transform..." << endl;
+//			cerr << "No suitable cached transform found - creating a new proofing transform..." << endl;
 			transform=new CMSProofingTransform(srcprofile,destprofile,proofprofile,intent,displayintent);
 			new CMTransformFactoryNode(this,transform,*d1,*d2,intent,true);
 		}
 	}
-	delete destprofile;
 
 	return(transform);
 }
@@ -541,7 +579,7 @@ ProfileInfo *ProfileManager::GetFirstProfileInfo()
 
 void ProfileManager::BuildProfileInfoList()
 {
-	cerr << "Building ProfileInfo List:" << endl;
+//	cerr << "Building ProfileInfo List:" << endl;
 	const char *f=NULL;
 	FlushProfileInfoList();
 	while((f=GetNextFilename(f)))
@@ -550,7 +588,7 @@ void ProfileManager::BuildProfileInfoList()
 			new ProfileInfo(*this,f);
 	}
 	GetProfileFromDisplay();
-	if(proffromdisplay)
+	if(proffromdisplay_size)
 		new ProfileInfo(*this,SYSTEMMONITORPROFILE_ESCAPESTRING);
 }
 
@@ -579,6 +617,31 @@ ProfileInfo *ProfileManager::FindProfileInfo(const char *filename)
 }
 
 
+int ProfileManager::GetProfileInfoCount()
+{
+	int c=0;
+	ProfileInfo *pi=GetFirstProfileInfo();
+	while(pi)
+	{
+		++c;
+		pi=pi->Next();
+	}
+	return(c);
+}
+
+
+ProfileInfo *ProfileManager::GetProfileInfo(int i)
+{
+	ProfileInfo *pi=GetFirstProfileInfo();
+	while(i && pi)
+	{
+		--i;
+		pi=pi->Next();
+	}
+	return(pi);
+}
+
+
 // ProfileInfo
 
 
@@ -617,7 +680,7 @@ void ProfileInfo::GetInfo()
 {
 	if(iscached)
 		return;
-	cerr << "Getting profile info for " << filename << endl;
+//	cerr << "Getting profile info for " << filename << endl;
 
 	CMSProfile *profile=profilemanager.GetProfile(filename);
 	if(profile)
@@ -683,32 +746,43 @@ const char *ProfileManager::GetIntentDescription(LCMSWrapper_Intent intent)
 
 void ProfileManager::GetProfileFromDisplay()
 {
-#ifndef WIN32
-	Display *dpy;
+#ifdef WIN32
+	HDC handle=GetDC(0);	// Get the default screen handle
+	DWORD dpsize=sizeof(displayprofilename)-1;
 
+	// Older Mingw wingdi.h files have a faulty definition of the following function,
+	// with the second param as DWORD instead of LPDWORD.
+	if(GetICMProfile(handle,&dpsize,displayprofilename))
+	{
+		proffromdisplay_size=dpsize;
+		cerr << "Got profile: " << displayprofilename << ", " << displayprofilename << " characters" << endl;
+	}
+	else
+		cerr << "No profile associated with default display." << endl;
+#else
 	if(proffromdisplay)
 		XFree(proffromdisplay);
 	proffromdisplay=NULL;
 
-	if((dpy = XOpenDisplay(NULL)))
+	if(xdisplay)
 	{
-		cerr << "Got display" << endl;
+//		cerr << "Got display" << endl;
 		Atom icc_atom;
-		icc_atom = XInternAtom (dpy, "_ICC_PROFILE", False);
+		icc_atom = XInternAtom (xdisplay, "_ICC_PROFILE", False);
 		if (icc_atom != None)
 		{
-			cerr << "Got atom" << endl;
-			Window w=DefaultRootWindow(dpy);
+//			cerr << "Got atom" << endl;
+			Window w=DefaultRootWindow(xdisplay);
 			if(w)
 			{
-				cerr << "Got window" << endl;
+//				cerr << "Got window" << endl;
 				Atom type;
 				int format=0;
 				unsigned long nitems=0;
 				unsigned long bytes_after=0;
 				int result=0;
 
-				result = XGetWindowProperty (dpy, w, icc_atom, 0,
+				result = XGetWindowProperty (xdisplay, w, icc_atom, 0,
 					0x7fffffff,0, XA_CARDINAL,
 					&type, &format, &nitems,
 					&bytes_after, &proffromdisplay);
