@@ -1,10 +1,14 @@
 #ifndef COLOURMANAGEMENT_H
 #define COLOURMANAGEMENT_H
 
-#include "../imagesource/imagesource.h"
+#include "imagesource.h"
 #include "lcmswrapper.h"
-#include "../support/configdb.h"
-#include "../support/searchpath.h"
+#include "configdb.h"
+#include "searchpath.h"
+
+#ifndef WIN32
+#include <X11/Xlib.h>
+#endif
 
 enum CMColourDevice
 {
@@ -48,6 +52,8 @@ class ProfileManager : public ConfigDB, public SearchPath
 	virtual void ClearPaths();
 	virtual const char *GetNextFilename(const char *prev);
 	ProfileInfo *GetFirstProfileInfo();
+	ProfileInfo *GetProfileInfo(int i);
+	int GetProfileInfoCount();
 	ProfileInfo *FindProfileInfo(const char *fn);
 	int GetIntentCount();
 	const char *GetIntentName(LCMSWrapper_Intent intent);
@@ -59,7 +65,12 @@ class ProfileManager : public ConfigDB, public SearchPath
 	void FlushProfileInfoList();
 	ProfileInfo *first;
 	void GetProfileFromDisplay();
+	#ifdef WIN32
+	char displayprofilename[MAX_PATH];
+	#else
+	Display *xdisplay;
 	unsigned char *proffromdisplay;
+	#endif
 	long proffromdisplay_size;
 	friend class ProfileInfo;
 };
