@@ -4,6 +4,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gtk/gtkcombobox.h>
+#include <gtk/gtkliststore.h>
 #include <gtk/gtkcombo.h>
 #include <gtk/gtkcheckbutton.h>
 #include <gtk/gtkvbox.h>
@@ -11,6 +13,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtkmenu.h>
+#include <gtk/gtktooltips.h>
 
 #include "profilemanager.h"
 
@@ -28,14 +31,18 @@ typedef struct _ProfileSelectorClass ProfileSelectorClass;
 struct _ProfileSelector
 {
 	GtkVBox box;
-	GtkWidget *description;
+//	GtkWidget *description;
 	GtkWidget *optionmenu;
 	GtkWidget *menu;
 	GList *optionlist;
+	GtkListStore *liststore;
+	GtkWidget *combobox;
+	GtkTooltips *tips;
 	ProfileManager *pm;
 	IS_TYPE colourspace;
 	bool allowdevicelink;
 	gchar *filename;
+	int currentidx;
 };
 
 
