@@ -8,8 +8,11 @@
 #include "patheditor.h"
 #include "imageselector.h"
 
-#include "../config.h"
-#include "../gettext.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "gettext.h"
 
 using namespace std;
 
@@ -34,7 +37,7 @@ class Test
 		gtk_container_add (GTK_CONTAINER (window), vbox);
 		gtk_widget_show (vbox);
 		
-		ps = profileselector_new(&pm,IS_TYPE_CMYK);
+		ps = profileselector_new(&pm,IS_TYPE_RGB);
 		g_signal_connect(ps,"changed",G_CALLBACK(profile_changed),this);
 		gtk_box_pack_start(GTK_BOX(vbox),ps,FALSE,FALSE,8);
 		gtk_widget_show(ps);
