@@ -1,7 +1,14 @@
 #include <stdio.h>
+#include <string.h>
 
 #include "printerqueues.h"
 
+static char *getfilename(void *userdata)
+{
+	return(strdup("/tmp/testprintcapture"));
+}
+
+
 int main(int argc,char **argv)
 {
 	struct pqinfo *pq;
@@ -25,14 +32,18 @@ int main(int argc,char **argv)
 				printf("(driver unknown)\n");
 		}
 
-/*
+#ifdef WIN32
 		pq->SetPrinterQueue(pq,"Epson Stylus Photo R300");
+		pq->SetGetFilenameCallback(pq,getfilename,NULL);
+#else
+		pq->SetPrinterQueue(pq,PRINTERQUEUE_CUSTOMCOMMAND);
+		pq->SetCustomCommand(pq,"cat >test.prn");
+#endif
 		pq->InitialiseJob(pq);
 		pq->InitialisePage(pq);
 		pq->WriteData(pq,message,strlen(message));
 		pq->EndPage(pq);
 		pq->EndJob(pq);
-*/
 
 		pq->Dispose(pq);
 	}
