@@ -22,15 +22,18 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 
-#include <egg-pixbuf-thumbnail.h>
+#include "egg-pixbuf-thumbnail.h"
 #include "generaldialogs.h"
 
 #include "imageselector.h"
 
 #include "imageselector_noborder_image.h"
 
-#include "../config.h"
-#include "../gettext.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "gettext.h"
  
 #define _(x) gettext(x)
 
