@@ -1,5 +1,6 @@
+#include <cstdlib>
+#include <cstring>
 #include <iostream>
-#include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
 
