@@ -6,7 +6,7 @@
 class SearchPathDBHandler : public ConfigDBHandler
 {
 	public:
-	SearchPathDBHandler(ConfigFile *file,const char *section,ConfigDB *db,SearchPath *sp,char *pathparam)
+	SearchPathDBHandler(ConfigFile *file,const char *section,ConfigDB *db,SearchPath *sp,const char *pathparam)
 		: ConfigDBHandler(file,section,db), db(db), sp(sp), pathparameter(pathparam)
 	{
 	}
